@@ -281,17 +281,17 @@ void QGeoPositionInfoSource::setPreferredPositioningMethods(PositioningMethods m
     // method, so we can't have a simple check like:
     // if (currentMethods == methods) return;
     // Instead we need to save the current value and compare it afterwards
-    const auto prevMethods = d->methods.valueBypassingBindings();
+    const auto prevMethods = d->methods.value();
 
     if (supportedPositioningMethods() != QGeoPositionInfoSource::NoPositioningMethods) {
         d->methods.setValueBypassingBindings(methods & supportedPositioningMethods());
-        if (d->methods.valueBypassingBindings() == 0) {
+        if (d->methods.value() == 0) {
             d->methods.setValueBypassingBindings(supportedPositioningMethods());
         }
     } else { // avoid that turned of Location service blocks any changes to d->methods
         d->methods.setValueBypassingBindings(methods);
     }
-    if (prevMethods != d->methods.valueBypassingBindings())
+    if (prevMethods != d->methods.value())
         d->methods.notify();
 }
 
@@ -349,7 +349,7 @@ QGeoPositionInfoSource *QGeoPositionInfoSource::createDefaultSource(QObject *par
 QGeoPositionInfoSource *QGeoPositionInfoSource::createDefaultSource(const QVariantMap &parameters, QObject *parent)
 {
     const QList<QCborMap> plugins = QGeoPositionInfoSourcePrivate::pluginsSorted();
-    foreach (const QCborMap &obj, plugins) {
+    for (const QCborMap &obj : plugins) {
         if (obj.value(QStringLiteral("Position")).isBool()
                 && obj.value(QStringLiteral("Position")).toBool()) {
             QGeoPositionInfoSource *source = QGeoPositionInfoSourcePrivate::createSourceReal(obj, parameters, parent);
